# Topsis-Aashish-101917110

Submitted By: Aashish Bansal

## Installation

```pip install Topsis-Aashish-101917110```

## How to use it?

```
import topsis
topsis.topsis("data.csv", "1,0.5,1,1", "+,-,+,-")
```

## License

© 2022 Aashish Bansal

This repository is licensed under the MIT license. See LICENSE for details.
